const FrameModule = require("ui/frame");
const Dialogs = require("ui/dialogs");
const fs = require("file-system");
const FeedbackPlugin = require("nativescript-feedback");
const permissionsPlugin = require('nativescript-permissions');


const config = require("../shared/config");
const LMS = require("../shared/lms").LMS;
const lms = new LMS();

const createViewModel = require("./playlists-view-model").createViewModel;

var viewModel;
var plsParms = {};

function onNavigatingTo(args) {
	var page = args.object;

	viewModel = createViewModel( lms);
	page.bindingContext = viewModel;
}

function navigateToPlsDL(args) {
	const that = this;
	const playlistId = args.object.bindingContext.playlists.getItem(args.index).playlistId;
	const feedback = new FeedbackPlugin.Feedback();

	plsParms.playlistName = args.object.bindingContext.playlists.getItem(args.index).playlistName;
	console.log("navigateToPlsDL playlistId="+playlistId+ " name="+plsParms.playlistName);

	viewModel.isLoading = true;

	lms.getPlaylist( playlistId)
		.then(function( result) {
			console.log("getPlaylist result size:"+result.length);
			viewModel.isLoading = false;
			var plsToWrite = '#EXTM3U\n';
			var theURL;
			for( let e of result) {
				plsToWrite += "#EXTINF:"+Math.floor( e.trackDuration)+","+e.trackArtist+" - "+e.trackTitle+"\n";
				try{
					theURL = decodeURI( e.trackUrl);
					plsToWrite += theURL.replace( config.settings.plsRegex, config.settings.plsSubst)+"\n";
				} catch( x) {
					console.log("getPlaylist Track:"+e.trackTitle+" URL:"+e.trackUrl);
				}
			}
			
			permissionsPlugin.requestPermission(android.Manifest.permission.WRITE_EXTERNAL_STORAGE, "Need write access to storage to save playlist")
				.then(function() {
					const path = fs.path.join( config.settings.plsPath, plsParms.playlistName+".m3u");
					//const path = fs.path.join( fs.knownFolders.documents().path, plsParms.playlistName+".m3u");
					try {
						const file = fs.File.fromPath(path);
						file.writeText( plsToWrite)
							.then(function () {
								feedback.success({
									title: "Playlist written",
									message: "Playlist ["+plsParms.playlistName+"]\nwritten successfully to\n"+path
								});
							}, function ( error) {
								feedback.error({
									title: "File error",
									message: "Error writing ["+plsParms.playlistName+"] to\n"+path+"\nCheck free space etc.\n[Tap for the gory details]",
									duration: 5000,
									onTap: () => {  
										Dialogs.alert( {
											title: "File error",
											message: "Path: "+path+"\nError:"+x.message,
											okButtonText: "OK"
										});
									}
								});
								console.log( error);
							});
					} catch( x) {
						feedback.error({
							title: "File error",
							message: "Error writing ["+plsParms.playlistName+"] to\n"+path+"\nCheck write access etc.\n[Tap for the gory details]",
							duration: 5000,
							onTap: () => {  
								Dialogs.alert( {
									title: "File error",
									message: "Path: "+path+"\nError:"+x.message,
									okButtonText: "OK"
								});
							}
						});
						console.log( x);
					}

				})
				.catch(function() {
					feedback.error({
						title: "No write access",
						message: "Write access not granted - operation canceled",
						duration: 5000
					});
			});

		},function(error) {
			lms.showLMSError( error);
			viewModel.isLoading = false;
			console.log(error);
		});
	 
}

exports.onGoBack = function( args) {
	FrameModule.topmost().goBack();
}

exports.onNavigatingTo = onNavigatingTo;
exports.navigateToPlsDL = navigateToPlsDL;