const Observable = require("data/observable").Observable;
const ObservableArray = require("data/observable-array").ObservableArray;

const LMS = require("../shared/lms").LMS;
const config = require("../shared/config");

function createViewModel(ldb, searchText) {
    var viewModel = new Observable({
		artists: new ObservableArray([]),
		albums: new ObservableArray([]),
		tracks: new ObservableArray([]),
		searchText: searchText,
		handleTracks: config.settings.handleTracks
	});

	const lms = new LMS();

    viewModel.select = function() {

		var collArtists = ldb.getCollection("artists");
		var collAlbums = ldb.getCollection("albums");
		var collTracks = ldb.getCollection("tracks");

		while (viewModel.artists.length) {
     	   viewModel.artists.pop();
    	}
		while (viewModel.albums.length) {
     	   viewModel.albums.pop();
    	}
		while (viewModel.tracks.length) {
     	   viewModel.tracks.pop();
    	}

		console.log("find "+viewModel.searchText);
		var t = collArtists.chain().find( {'artistName': { '$regex': [ viewModel.searchText, 'i'] }}).simplesort("artistName").data();
		for( let e of t) {
			//console.log( "select id:" + e.artistId + " artistName:" + e.artistName);
			viewModel.artists.push( { "artistId": e.artistId, "artistName": e.artistName });
		}

		t = collAlbums.chain().find( {'albumName': { '$regex': [ viewModel.searchText, 'i'] }}).simplesort("albumName").data();
		for( let e of t) {
			//console.log( "select id:" + e.albumId + " albumName:" + e.albumName);
			viewModel.albums.push( { "albumId": e.albumId, "albumName": e.albumName, "albumArtist": e.albumArtist, "albumYear": e.albumYear });
		}

		if( config.settings.handleTracks) {
			t = collTracks.chain().find( {'trackTitle': { '$regex': [ viewModel.searchText, 'i'] }}).simplesort("trackTitle").data();
			var doc;
			for( let e of t) {
				doc = new Object();
				for (const tatt of Object.keys(lms.trackMap.item)) {
					doc[tatt] = e[tatt];
				}
				viewModel.tracks.push( doc);
			}
		}

    }

    viewModel.select();

    return viewModel;
}

exports.createViewModel = createViewModel;
