const FrameModule = require("ui/frame");
const Dialogs = require("ui/dialogs");
const colorModule = require("color");

//const LoadingIndicator = require("nativescript-loading-indicator").LoadingIndicator;
const FeedbackPlugin = require("nativescript-feedback");
const feedback = new FeedbackPlugin.Feedback();

const LMS = require("../shared/lms").LMS;
const config = require("../shared/config");
const createViewModel = require("./settings-view-model").createViewModel;

var viewModel;

function onNavigatingTo(args) {
    var page = args.object;

	if( !viewModel) {
		viewModel = createViewModel();
	}
	page.bindingContext = viewModel;

}
exports.onNavigatingTo = onNavigatingTo;

exports.importLibButtonOnTap = function( args) {

	config.settings.apiUrl = viewModel.get("lmsUrl");

	const collArtists = global.ldb.getCollection("artists");
	const collAlbums = global.ldb.getCollection("albums");
	const collTracks = global.ldb.getCollection("tracks");

/*
	const liProgressInterface = {
		loader: new LoadingIndicator(),
		internal: {
			maxVal: 0,
			isBusy: false
		},
		options: {
			message: 'Please wait...',
			progress: 0,
			android: {
				indeterminate: false,
				cancelable: false,
				max: 100,
//				progressNumberFormat: "%1d/%2d",
//				progressPercentFormat: 0.53,
				progressStyle: 1,
//				secondaryProgress: 1
			},
			ios: {
				dimBackground: true,
			}
		},
		setBusy: function( isBusy) {
			this.internal.isBusy = isBusy;
			if( isBusy) {
				this.loader.show( this.options);
			} else {
				this.loader.hide();
			}
		},
		setMaxValue: function( maxVal) {
			this.internal.maxVal = maxVal;
			//this.options.android.max = maxVal;
		},
		setCurrValue: function( prog) {
			this.options.progress = prog==0?0:prog/this.internal.maxVal;
			//this.options.progress = prog;
			console.dump( this.options);
			if( this.internal.isBusy) {
				this.loader.hide();
				this.loader.show( this.options);
			}
			console.log("liProgressInterface: %="+this.options.progress);
		},
		setMessage: function( theMsg) {
			this.options.message = theMsg;
			if( this.internal.isBusy) {
				this.loader.hide();
				this.loader.show( this.options);
				console.log("liProgressInterface: msg="+theMsg);
			}
		},

	};
*/
	const vmProgressInterface = {
		setBusy: function( isBusy) {
			viewModel.isLoading = isBusy;
		},
		setMaxValue: function( maxVal) {
			viewModel.progressMaxVal = maxVal;
		},
		setCurrValue: function( prog) {
			viewModel.importProgress = prog;
		},
		setMessage: function( theMsg) {
			feedback.info({
				title: "Library import",
				message: theMsg,
			});
		},
	};

	vmProgressInterface.setMessage( "Starting import - Artists");
	vmProgressInterface.setBusy( true);
	vmProgressInterface.setCurrValue( 0);

	const lms = new LMS();
	lms.checkConn();


	lms.getAllArtists()
		.then(function( result) {
			//console.dump( result);
			vmProgressInterface.setMessage( result.length+" artists imported - importing albums");
			console.log("getAllArtists result size:"+result.length);
			collArtists.clear();
			collArtists.insert( result);

			lms.getAllAlbums()
				.then(function( result) {
					//console.dump( result);
					vmProgressInterface.setMessage( result.length+" albums imported - importing tracks");
					console.log("getAllAlbums result size:"+result.length);
					collAlbums.clear();
					collAlbums.insert( result);
					if( config.settings.handleTracks) {
						lms.getAllTracks( collTracks, vmProgressInterface);
					} else {
						vmProgressInterface.setBusy( false);
						vmProgressInterface.setMessage( result.length+" albums imported - Import done");
					}
				},function(error) {
					console.log(error);
					vmProgressInterface.setBusy( false);
					lms.showLMSError( error);
				});

		},function(error) {
			console.log(error);
			vmProgressInterface.setBusy( false);
			lms.showLMSError( error);
		});
	
}

exports.importCoversButtonOnTap = function() {
}

exports.saveDBButtonOnTap = function() {
	global.ldb.saveDatabase( function( err) {
		console.log("db save");
		if( err) {
			feedback.error({
				title: "Save Database",
				message: "Database save error:\n"+err,
			});
			console.dump( err);
		} else {
			feedback.success({
				title: "Save Database",
				message: "Database saved successfully",
			});
		}
	});
}

exports.aboutButtonOnTap = function() {
	const Color = colorModule.Color;
	feedback.info({
		title: "LMSlib2go",
		titleColor: new Color("Red"),
		message: "Author: R.S.U.\nWeb: https://www.nexus0.net/pub/sw/lmslib2go\nLicense: GPL v3\nSW used: NativeScript, LokiJS, node json transform",
		messageColor: new Color("GhostWhite"),
		duration: 30000,
		backgroundColor: new Color("DarkSlateGray"),
		//icon: "icon", // in App_Resources/platform folders
	});
}

exports.onGoBack = function( args) {
	FrameModule.topmost().goBack();
}

exports.onFetchSizeChange = function( args) {
	if( args.propertyName == "text") {
		config.settings.fetchChunks = +args.value;
	    console.log("fetchSize="+config.settings.fetchChunks);
	}
}
exports.onLmsUrlChange = function( args) {
	if( args.propertyName == "text") {
		config.settings.apiUrl = args.value;
	    console.log("apiUrl="+config.settings.apiUrl);
	}
}
exports.onDarkThemeChange = function( args) {
	if( args.propertyName == "checked") {
		if( args.value) {
			config.settings.appTheme = "dark";
		} else {
			config.settings.appTheme = "light";
		}
	    console.log("appTheme="+config.settings.appTheme);
	}
}
exports.onHandleTracksChange = function( args) {
	if( args.propertyName == "checked") {
		if( args.value) {
			config.settings.handleTracks = true;
		} else {
			config.settings.handleTracks = false;
		}
	    console.log("handleTracks="+config.settings.handleTracks);
	}
}
exports.onPlsRegexChange = function( args) {
	config.settings.plsRegex = args.object.text;
	console.log("config.settings.plsRegex="+config.settings.plsRegex);
}
exports.onPlsSubstChange = function( args) {
	config.settings.plsSubst = args.object.text;
	console.log("config.settings.plsSubst="+config.settings.plsSubst);
}
exports.onPlsPathChange = function( args) {
	config.settings.plsPath = args.object.text;
	console.log("config.settings.plsPath="+config.settings.plsPath);
}