const Observable = require("data/observable").Observable;
const ObservableArray = require("data/observable-array").ObservableArray;

const LMS = require("../shared/lms").LMS;
const config = require("../shared/config");
const utils = require("../shared/utils");

function createViewModel(collTracks, artistId, albumId) {
	const lms = new LMS();
	var viewModel = new Observable( {
		tracks: new ObservableArray([]),
		albumId: albumId,
		artistId: artistId,
		trackFilter: "",
		showMoreInfo: true
	});

    viewModel.select = function() {
		var sortCol = "trackTitle";
		this.showMoreInfo = true;

		while (this.tracks.length) {
     	   this.tracks.pop();
    	}

		var filterExp = {};
		if( this.albumId) {
			filterExp = {'trackAlbumId': { '$eq' : this.albumId }};
			sortCol = "trackTracknum";
			this.showMoreInfo = false;
		} else if( this.artistId) {
			filterExp = {'trackArtistIds': { '$contains' : this.artistId }};
			this.showMoreInfo = false;
		}

		if( this.trackFilter) {
			//Object.assign( filterExp, {'trackTitle': { '$contains' : this.trackFilter }});
			filterExp = { "$and": [filterExp, {'trackTitle': { '$regex': [ viewModel.trackFilter, 'i'] }}]};
			console.dump( filterExp);
		}

		console.log("track find albumId="+this.albumId + " artistId="+this.artistId+" trackFilter="+this.trackFilter);
		var t = collTracks.chain().find( filterExp).simplesort( sortCol).data();

		/*
		if( filterExp.trackAlbumId) {
			console.dump(filterExp);
			console.dump(t);
		}
		*/

		var doc;
		for( let e of t) {
			doc = new Object();
			for (const tatt of Object.keys(lms.trackMap.item)) {
				if( lms.trackAttributes[tatt] && lms.trackAttributes[tatt].funct) {
					try {
						doc[tatt] = lms.trackAttributes[tatt]['funct'](e[tatt]);
					} catch( x) {
						doc[tatt] = e[tatt];
						console.log("Tid "+e['trackId']+" Attribute "+tatt + " Element "+e[tatt]+" Error "+x);
//						console.dump (e);
					}
				} else {
					doc[tatt] = e[tatt];
				}
				//doc[tatt] = e[tatt];
			}
			//doc.icon = config.icons.info;
			doc.showMoreInfo = this.showMoreInfo;
			this.tracks.push( doc);
		}
    }

    viewModel.select();

    return viewModel;
}

exports.createViewModel = createViewModel;
